summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kopeteiface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/kopeteiface.h')
-rw-r--r--kopete/kopete/kopeteiface.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kopete/kopete/kopeteiface.h b/kopete/kopete/kopeteiface.h
index 4ca4c4d1..46a52166 100644
--- a/kopete/kopete/kopeteiface.h
+++ b/kopete/kopete/kopeteiface.h
@@ -19,7 +19,7 @@
#define KopeteIface_h
#include <dcopobject.h>
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kurl.h>
#include "kopeteonlinestatus.h"
@@ -35,35 +35,35 @@ public:
KopeteIface();
k_dcop:
- QStringList contacts();
- QStringList reachableContacts();
- QStringList onlineContacts();
- QStringList fileTransferContacts();
- QStringList contactFileProtocols(const QString &displayName);
+ TQStringList contacts();
+ TQStringList reachableContacts();
+ TQStringList onlineContacts();
+ TQStringList fileTransferContacts();
+ TQStringList contactFileProtocols(const TQString &displayName);
- /*void sendFile(const QString &displayName, const KURL &sourceURL,
- const QString &altFileName = QString::null, uint fileSize = 0);*/
+ /*void sendFile(const TQString &displayName, const KURL &sourceURL,
+ const TQString &altFileName = TQString::null, uint fileSize = 0);*/
// FIXME: Do we *need* this one? Sounds error prone to me, because
// nicknames can contain parentheses too.
- // Better add a contactStatus( const QString id ) I'd say - Martijn
- QStringList contactsStatus();
+ // Better add a contactStatus( const TQString id ) I'd say - Martijn
+ TQStringList contactsStatus();
/**
* Open a chat to a contact, and optionally set some initial text
*/
- QString messageContact( const QString &contactId, const QString &messageText = QString::null );
+ TQString messageContact( const TQString &contactId, const TQString &messageText = TQString::null );
/**
* Describe the status of a contact by their metaContactId,
* aka their uid in KABC.
*/
- QString onlineStatus( const QString &metaContactId );
+ TQString onlineStatus( const TQString &metaContactId );
/**
* Message a contact by their metaContactId, aka their uid in KABC.
*/
- void messageContactById( const QString &metaContactId );
+ void messageContactById( const TQString &metaContactId );
/**
* Adds a contact with the specified params.
@@ -75,23 +75,23 @@ k_dcop:
* @param groupName The name of the group to add the contact to
* @return Weather or not the contact was added successfully
*/
- bool addContact( const QString &protocolName, const QString &accountId, const QString &contactId,
- const QString &displayName, const QString &groupName = QString::null );
+ bool addContact( const TQString &protocolName, const TQString &accountId, const TQString &contactId,
+ const TQString &displayName, const TQString &groupName = TQString::null );
/**
* return a list of alls accounts.
* form: XXXProtocol||AccountId
*/
- QStringList accounts();
+ TQStringList accounts();
/**
* connect a given account in the given protocol
*/
- void connect(const QString &protocolName, const QString &accountId);
+ void connect(const TQString &protocolName, const TQString &accountId);
/**
* disconnect a given account in the given protocol
*/
- void disconnect(const QString &protocolName, const QString &accountId);
+ void disconnect(const TQString &protocolName, const TQString &accountId);
/**
* Ask all accounts to connect
@@ -108,13 +108,13 @@ k_dcop:
* the name is the name of the library: example: kopete_msn
* but you can ommit the kopete_ prefix
*/
- bool loadPlugin( const QString& name );
+ bool loadPlugin( const TQString& name );
/**
* unload a plugin
* the name is the name of the library: example: kopete_msn
* but you can ommit the kopete_ prefix
*/
- bool unloadPlugin( const QString& name );
+ bool unloadPlugin( const TQString& name );
/**
* set all account away using the global away function
@@ -125,14 +125,14 @@ k_dcop:
* set all account away using the global away function
* and set an away message
*/
- void setAway( const QString &msg ) { setAway( msg, true ); }
+ void setAway( const TQString &msg ) { setAway( msg, true ); }
/**
* set all account away using the global away function
* and set an away message.
* @param away decides if the message is away/non-away
*/
- void setAway( const QString &msg, bool away );
+ void setAway( const TQString &msg, bool away );
/**
* set Available all accountes
@@ -148,7 +148,7 @@ k_dcop:
* set the global nickname if global identity is enabled.
* @param nickname the new global nickname
*/
- void setGlobalNickname( const QString &nickname );
+ void setGlobalNickname( const TQString &nickname );
/**
* set the global photo if global identity is enabled.
@@ -160,13 +160,13 @@ k_dcop:
* get the contactIds for a given display name
* @param displayName
*/
- QStringList contactsForDisplayName( const QString & displayName );
+ TQStringList contactsForDisplayName( const TQString & displayName );
/**
* get the metacontactIds that have the given contactId
* @param contactId
*/
- QStringList metacontactsForContactId( const QString & contactId );
+ TQStringList metacontactsForContactId( const TQString & contactId );
};
#endif